@@ -1,11 +1,11 @@
 from .dreamer import *
 from .utils import *
-from .simple import *
+from .models import *
 
-__version__ = "0.0.2"
+__version__ = "1.1.0"
 
 __all__ = [
     "dreamer",
     "utils",
-    "simple"
+    "models"
 ]
\ No newline at end of file
